@@ -29,7 +29,7 @@ import os
 import urllib
 import urllib2
 import pkg_resources
-from slapos.lib.recipe.BaseSlapRecipe import BaseSlapRecipe
+from slapos.recipe.librecipe import BaseSlapRecipe
 
 class NoSQLTestBed(BaseSlapRecipe):
 
@@ -37,16 +37,13 @@ class NoSQLTestBed(BaseSlapRecipe):
     self.parameter_dict = self.computer_partition.getInstanceParameterDict()
     software_type = self.parameter_dict.get('slap_software_type', 'default')
     if software_type is None or software_type == 'RootSoftwareInstance':
-      software_type = 'default'
+      software_type = 'kumo_cloud'
     if "run_%s" % software_type in dir(self) and \
        callable(getattr(self, "run_%s" % software_type)):
       return getattr(self, "run_%s" % software_type)()
     else:
       raise NotImplementedError("Do not support %s" % software_type)
 
-  def run_default(self):
-    return None
-
   def run_kumo_cloud(self):
     """ Deploy kumofs systeom on a cloud. """
 
@@ -61,13 +58,16 @@ class NoSQLTestBed(BaseSlapRecipe):
       kumo_cloud_config['nb_server_max'] = 3
     
     if 'nb_tester_max' not in kumo_cloud_config:
-      kumo_cloud_config['nb_tester_max'] = 3
+      kumo_cloud_config['nb_tester_max'] = 1 # 3
     
     if 'nb_thread' not in kumo_cloud_config:
-      kumo_cloud_config['nb_thread'] = 1
+      kumo_cloud_config['nb_thread'] = 32 # 1
     
     if 'nb_request' not in kumo_cloud_config:
-      kumo_cloud_config['nb_request'] = 1000
+      kumo_cloud_config['nb_request'] = 1024000 # 1000
+    
+    if 'computer_guid_list' not in kumo_cloud_config:
+      kumo_cloud_config['computer_guid_list'] = "COMP-9:COMP-10:COMP-11"
     
     kumo_cloud_config['software_release_url'] = self.software_release_url
     kumo_cloud_config['server_url'] = self.server_url
@@ -79,6 +79,7 @@ class NoSQLTestBed(BaseSlapRecipe):
 
     kumo_cloud_connection = {}
     kumo_cloud_connection['url'] = "http://["+kumo_cloud_config['address']+"]:5000/"
+    kumo_cloud_connection['computer_guid_list'] = kumo_cloud_config['computer_guid_list']
     self.computer_partition.setConnectionDict(kumo_cloud_connection)
 
     nosqltester_manager_wrapper_template_location = pkg_resources.resource_filename(
